API Reference
=============

This section contains the complete API reference.

Main Interface
--------------

.. automodule:: subscriptionkore
   :members:
   :undoc-members:
   :show-inheritance:
   :no-index:

Configuration
-------------

.. automodule:: subscriptionkore.config
   :members:
   :undoc-members:
   :show-inheritance:

Core Models
-----------

.. automodule:: subscriptionkore.core.models.subscription
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: subscriptionkore.core.models.customer
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: subscriptionkore.core.models.plan
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: subscriptionkore.core.models.product
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: subscriptionkore.core.models.invoice
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: subscriptionkore.core.models.payment_event
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: subscriptionkore.core.models.entitlement
   :members:
   :undoc-members:
   :show-inheritance:

Value Objects
-------------

.. automodule:: subscriptionkore.core.models.value_objects
   :members:
   :undoc-members:
   :show-inheritance:

Events
------

.. automodule:: subscriptionkore.core.events
   :members:
   :undoc-members:
   :show-inheritance:
   :no-index:

Exceptions
----------

.. automodule:: subscriptionkore.core.exceptions
   :members:
   :undoc-members:
   :show-inheritance:

Adapters
--------

.. automodule:: subscriptionkore.adapters.stripe
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: subscriptionkore.adapters.chargebee
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: subscriptionkore.adapters.paddle
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: subscriptionkore.adapters.lemonsqueezy
   :members:
   :undoc-members:
   :show-inheritance:

Services
--------

.. automodule:: subscriptionkore.services
   :members:
   :undoc-members:
   :show-inheritance:

Integrations
------------

.. automodule:: subscriptionkore.integrations
   :members:
   :undoc-members:
   :show-inheritance: